summaryrefslogtreecommitdiff
path: root/actions/api.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@controlyourself.ca>2009-02-26 13:22:51 -0800
committerEvan Prodromou <evan@controlyourself.ca>2009-02-26 13:22:51 -0800
commit34a61b40f47a52d1fdcf7cd907f3ac53b96b038e (patch)
tree14ddeb18d9e020760d8c2308a12d858b6eab4a17 /actions/api.php
parent478192fa3b2375a0ff0a5ff03956381e5da7a6ac (diff)
parent8c3fe83c645265a11a3fca80cac2ac48ea72cdab (diff)
Merge branch '0.7.x' into 0.8.x
Diffstat (limited to 'actions/api.php')
-rw-r--r--actions/api.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/actions/api.php b/actions/api.php
index 21fe4eea3..a27d24492 100644
--- a/actions/api.php
+++ b/actions/api.php
@@ -131,14 +131,14 @@ class ApiAction extends Action
'statuses/followers',
'favorites/favorites');
- # If the site is "private", all API methods need authentication
-
+ $fullname = "$this->api_action/$this->api_method";
+
+ // If the site is "private", all API methods except laconica/config
+ // need authentication
if (common_config('site', 'private')) {
- return true;
+ return $fullname != 'laconica/config' || false;
}
- $fullname = "$this->api_action/$this->api_method";
-
if (in_array($fullname, $bareauth)) {
# bareauth: only needs auth if without an argument
if ($this->api_arg) {